.. _minimize_user_api:

Minimize
--------

This module contains everything related to minimization in zfit.

Minimizers
##########

Click on the link to see the list of of minimizers.

.. toctree::
    :maxdepth: 1

    minimize/minimizers


Strategy
#############

Strategy to deal with NaNs and to provide callbacks.

.. toctree::
    :maxdepth: 1

    minimize/strategy



Criterion
#############

Criterion for the convergence of the minimization.

.. toctree::
    :maxdepth: 1

    minimize/criterion
